@@ -1,15 +1,36 @@
 """
-SysAll is a tool that allows you to retrieve information about the environment, 
-such as the name of the operating system, processor, RAM, IP address, MAC address of the machine.
+SysAll is a library that aims to make it easier for python developers,
+to use/manipulate data from the Windows environment.
 
-It gathers the functionalities of several libraries such as 
-wmi, psutil, platform, getmac, socket in one to facilitate the use/manipulation of environment data
-for Python programmers.
+With this tool, you will be able to access many system and network features. 
+All this with functions that can be modified at will and in a single library.
 """
 
-__version__ = '1.0.8'
+__copyright__  = """
+Copyright (c) 2023 LixNew; lixnew2@gmail.com
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
+
+__version__ = '1.1.1'
 __title__ = 'SysAll'
-__description__ = "Tool to easily retrieve information from the environment and the network"
+__description__ = "Tools to facilitate the use/manipulation of data in the Windows environment"
 __autor__ = 'LixNew'
 __twitter__ = '@LixNew2'
 __url__ = "https://github.com/LixNew2/SysAll"
@@ -27,7 +48,6 @@ import multiprocessing
 import ctypes
 import subprocess
 
-
 #System
 
 #Functions
@@ -81,14 +101,14 @@ def get_appdata(hostname : bool = True, appdata_path : bool = True) -> dict:
     #Dictionary that saves the returned information
     appdata_infos = {}
     
-    appdata_hostname = os.environ['APPDATA']
+    _appdata_hostname = os.environ['APPDATA']
     
     #If hostname (True) add hostname in appdata_infos
     if hostname:
-        appdata_infos["hostname"] = appdata_hostname.split('\\')[2]
+        appdata_infos["hostname"] = _appdata_hostname.split('\\')[2]
     #If appdata_path (True) add path in appdata_infos 
     if appdata_path:
-        appdata_infos["appdata_path"] = appdata_hostname
+        appdata_infos["appdata_path"] = _appdata_hostname
     
     #If one or more (True) return appdata_infos   
     if (hostname or appdata_path):  
@@ -145,29 +165,29 @@ def get_gpu_info(name: bool = True, ram: bool = True, driver_version: bool = Tru
     """
 
     #Variable
-    AMOUNT = 0
+    _AMOUNT = 0
     
     #WMI object initialisation
-    wmi_obj = wmi.WMI()
+    _wmi_obj = wmi.WMI()
     
     #Get all GPU on the system
-    gpus = wmi_obj.Win32_VideoController()
+    _gpus = _wmi_obj.Win32_VideoController()
     
     #Dictionary that saves the returned information
     gpu_infos = {}
     
     #For all GPU in GPUS get info
-    for gpu in gpus:
-        AMOUNT+=1
+    for _gpu in _gpus:
+        _AMOUNT+=1
         #If name (True) add name in gpu_infos
         if name:
-            gpu_infos[f"Name GPU{AMOUNT}"] = gpu.Name
+            gpu_infos[f"Name GPU{_AMOUNT}"] = _gpu.Name
         #If ram (True) add ram in gpu_infos    
         if ram:
-            gpu_infos[f"RAM GPU{AMOUNT}"] = gpu.AdapterRAM
+            gpu_infos[f"RAM GPU{_AMOUNT}"] = _gpu.AdapterRAM
         #If driver_version (True) add driver_version in gpu_infos
         if driver_version:
-            gpu_infos[f"Driver_Version GPU{AMOUNT}"] = gpu.DriverVersion
+            gpu_infos[f"Driver_Version GPU{_AMOUNT}"] = _gpu.DriverVersion
     
     #If one or more (True) returns gpu_infos
     if (name or ram or driver_version):         
@@ -194,24 +214,24 @@ def get_disk_infos(path: str = 'C', total : bool = True, free: bool = True, used
     disk_infos = {}
     
     #Get dick space
-    total_bytes = ctypes.c_ulonglong(0)
-    free_bytes = ctypes.c_ulonglong(0)
-    ctypes.windll.kernel32.GetDiskFreeSpaceExW(ctypes.c_wchar_p(path), None, ctypes.pointer(total_bytes), ctypes.pointer(free_bytes))
+    _total_bytes = ctypes.c_ulonglong(0)
+    _free_bytes = ctypes.c_ulonglong(0)
+    ctypes.windll.kernel32.GetDiskFreeSpaceExW(ctypes.c_wchar_p(path), None, ctypes.pointer(_total_bytes), ctypes.pointer(_free_bytes))
     
-    total_space = total_bytes.value
-    free_space = free_bytes.value
-    used_space = total_space - free_space
+    _total_space = _total_bytes.value
+    _free_space = _free_bytes.value
+    _used_space = _total_space - _free_space
     
     #If total (True) add infos in disk_infos
     if total:
-        disk_infos['total'] = f"{total_space / (1024**3):.2f}"
+        disk_infos['total'] = f"{_total_space / (1024**3):.2f}"
     #If free (True) add infos in disk_infos
     if free:
         
-        disk_infos['free'] = f"{free_space / (1024**3):.2f}"
+        disk_infos['free'] = f"{_free_space / (1024**3):.2f}"
     #If used (True) add infos in disk_infos
     if used:
-        disk_infos['used'] =  f"{used_space / (1024**3):.2f}"
+        disk_infos['used'] =  f"{_used_space / (1024**3):.2f}"
     
     #If one or more (True) return gpu_infos
     if (total or free or used):
@@ -239,46 +259,45 @@ def _network_infos():
     """Do not call"""
     
     net = subprocess.check_output('ipconfig /all')
-
     return net
 
 def get_gateway(net=_network_infos()) -> str:
     """Returns the default gateway address"""
     
-    for line in net.split(b'\r\n'):
-        if b'Default Gateway' in line or b'Passerelle par d' in line:
-            gateway = line.split(b':')[1].decode('utf-8').strip()
+    for _line in net.split(b'\r\n'):
+        if b'Default Gateway' in _line or b'Passerelle par d' in _line:
+            gateway = _line.split(b':')[1].decode('utf-8').strip()
             if gateway != "":
                 return gateway
             
 def get_submask(net=_network_infos()) -> str:
     """Returns the address of the sub-mask"""
     
-    for line in net.split(b'\r\n'):
-        if b'Subnet Mask' in line or b'Masque de sous-r' in line:
-            submask = line.split(b':')[1].decode('utf-8').strip()
+    for _line in net.split(b'\r\n'):
+        if b'Subnet Mask' in _line or b'Masque de sous-r' in _line:
+            submask = _line.split(b':')[1].decode('utf-8').strip()
             return submask
     
 def get_DNS(net=_network_infos()) -> str:
     """Returns the address of the DNS server"""
     
-    for line in net.split(b'\r\n'):
-        if b'DNS Servers' in line or b'Serveurs DNS' in line:
-            dns = line.split(b':')[1].decode('utf-8').strip()
+    for _line in net.split(b'\r\n'):
+        if b'DNS Servers' in _line or b'Serveurs DNS' in _line:
+            dns = _line.split(b':')[1].decode('utf-8').strip()
             if dns != "fec0":
                 return dns
             
-def get_DHCP_status(net=_network_infos()) -> str:
+def get_DHCP_status(net=_network_infos()) -> bool:
     """Returns the DHCP status
     
     If the function returns "True" it means that DHCP is enabled.
     On the contrary, if the function returns "False", it means that DHCP is disabled.
     """
     
-    for line in net.split(b'\r\n'):
-        if b'DHCP Enabled' in line or b'DHCP activ' in line:
-            dhcp_st = line.split(b':')[1].decode('utf-8').strip()
-            if dhcp_st == "Yes" or dhcp_st == "Oui":
+    for _line in net.split(b'\r\n'):
+        if b'DHCP Enabled' in _line or b'DHCP activ' in _line:
+            _dhcp_st = _line.split(b':')[1].decode('utf-8').strip()
+            if _dhcp_st == "Yes" or _dhcp_st == "Oui":
                 return True
             else:
                 return False  
@@ -286,8 +305,73 @@ def get_DHCP_status(net=_network_infos()) -> str:
 def get_DHCP(net=_network_infos()) -> str:
     """Returns the address of the DNS server"""
     
-    for line in net.split(b'\r\n'):
-        if b'DHCP Server' in line or b'Serveur DHCP' in line:
-            dhcp = line.split(b':')[1].decode('utf-8').strip()
+    for _line in net.split(b'\r\n'):
+        if b'DHCP Server' in _line or b'Serveur DHCP' in _line:
+            dhcp = _line.split(b':')[1].decode('utf-8').strip()
             if dhcp != "":
-                return dhcp
\ No newline at end of file
+                return dhcp
+            
+def get_node_type(net=_network_infos()) -> str:
+    """Returns the type of node"""
+    
+    for _line in net.split(b'\r\n'):
+        if b'Node Type' in _line or b'Type de noeud' in _line:
+            node = _line.split(b':')[1].decode('utf-8').strip()
+            if node != "":
+                return node
+
+def get_WINS_proxy_status(net=_network_infos()) -> bool:
+    """Returns WINS Proxy status
+    
+    If the function returns "True" it means that WINS proxy is enabled.
+    On the contrary, if the function returns "False", it means that WINS proxy is disabled.
+    """
+    
+    for _line in net.split(b'\r\n'):
+        if b'WINS Proxy Enabled' in _line or b'Proxy WINS activ' in _line:
+            _winx = _line.split(b':')[1].decode('utf-8').strip()
+            if _winx == "Yes" or _winx == "Oui":
+                return True
+            else:
+                return False
+            
+def get_IP_routing_status(net=_network_infos()) -> bool:
+    """Returns IP routing status
+    
+    If the function returns "True" it means that IP routing is enabled.
+    On the contrary, if the function returns "False", it means that IP routing is disabled.
+    """
+    
+    for _line in net.split(b'\r\n'):
+        if b'IP Routing Enabled' in _line or b'Routage IP activ' in _line:
+            _routing = _line.split(b':')[1].decode('utf-8').strip()
+            if _routing == "Yes" or _routing == "Oui":
+                return True
+            else:
+                return False
+            
+def get_main_DNS_suffix(net=_network_infos()) -> str:
+    """Returns main DNS status"""
+    
+    for _line in net.split(b'\r\n'):
+        if b'Priamry Dns Suffix' in _line or b'Suffixe DNS principal' in _line:
+            suffix_dns = _line.split(b':')[1].decode('utf-8').strip()
+            if suffix_dns != "":
+                return suffix_dns
+
+def get_automtic_config(net=_network_infos()) -> str:
+    """Returns Autoconfiguration status
+    
+    If the function returns "True" it means that Autoconfiguration is enabled.
+    On the contrary, if the function returns "False", it means that Autoconfiguration is disabled.
+    """
+    
+    for _line in net.split(b'\r\n'):
+        if b'Autoconfiguration Enabled' in _line or b'Configuration automatique activ' in _line:
+            _auto_conf = _line.split(b':')[1].decode('utf-8').strip()
+            if _auto_conf == "Yes" or _auto_conf == "Oui":
+                return True
+            else:
+                return False
+            
+            
\ No newline at end of file
